@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
-from functools import wraps
+from functools import wraps, WRAPPER_ASSIGNMENTS
 
 from django.http.response import HttpResponse
-from django.utils.decorators import available_attrs
 
 
 from rest_framework_extensions.settings import extensions_api_settings
-from django.utils import six
 
 
 def get_cache(alias):
@@ -14,7 +11,19 @@ def get_cache(alias):
     return caches[alias]
 
 
-class CacheResponse(object):
+class CacheResponse:
+    """
+    Store/Receive and return cached `HttpResponse` based on DRF response.
+
+
+    .. note::
+        This decorator will render and discard the original DRF response in
+        favor of Django's `HttpResponse`. The allows the cache to retain a
+        smaller memory footprint and eliminates the need to re-render
+        responses on each request. Furthermore it eliminates the risk for users
+        to unknowingly cache whole Serializers and QuerySets.
+
+    """
     def __init__(self,
                  timeout=None,
                  key_func=None,
@@ -39,7 +48,8 @@ class CacheResponse(object):
 
     def __call__(self, func):
         this = self
-        @wraps(func, assigned=available_attrs(func))
+
+        @wraps(func, assigned=WRAPPER_ASSIGNMENTS)
         def inner(self, request, *args, **kwargs):
             return this.process_cache_response(
                 view_instance=self,
@@ -56,6 +66,7 @@ class CacheResponse(object):
                                request,
                                args,
                                kwargs):
+
         key = self.calculate_key(
             view_instance=view_instance,
             view_method=view_method,
@@ -63,23 +74,29 @@ class CacheResponse(object):
             args=args,
             kwargs=kwargs
         )
-        response = self.cache.get(key)
-        if not response:
+
+        timeout = self.calculate_timeout(view_instance=view_instance)
+
+        response_triple = self.cache.get(key)
+        if not response_triple:
+            # render response to create and cache the content byte string
             response = view_method(view_instance, request, *args, **kwargs)
             response = view_instance.finalize_response(request, response, *args, **kwargs)
-            response.render()  # should be rendered, before picklining while storing to cache
+            response.render()
 
             if not response.status_code >= 400 or self.cache_errors:
-                response_dict = (
+                response_triple = (
                     response.rendered_content,
                     response.status_code,
-                    response._headers
+                    response._headers.copy()
                 )
-                self.cache.set(key, response_dict, self.timeout)
+                self.cache.set(key, response_triple, timeout)
         else:
-            content, status, headers = response
+            # build smaller Django HttpResponse
+            content, status, headers = response_triple
             response = HttpResponse(content=content, status=status)
-            response._headers = headers
+            for k, v in headers.values():
+                response[k] = v
 
         if not hasattr(response, '_closable_objects'):
             response._closable_objects = []
@@ -92,7 +109,7 @@ class CacheResponse(object):
                       request,
                       args,
                       kwargs):
-        if isinstance(self.key_func, six.string_types):
+        if isinstance(self.key_func, str):
             key_func = getattr(view_instance, self.key_func)
         else:
             key_func = self.key_func
@@ -104,5 +121,10 @@ class CacheResponse(object):
             kwargs=kwargs,
         )
 
+    def calculate_timeout(self, view_instance, **_):
+        if isinstance(self.timeout, str):
+            self.timeout = getattr(view_instance, self.timeout)
+        return self.timeout
+
 
 cache_response = CacheResponse
