@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 import logging
-from functools import wraps
+from functools import wraps, WRAPPER_ASSIGNMENTS
 
-from django.utils.decorators import available_attrs
 from django.utils.http import parse_etags, quote_etag
 
 from rest_framework import status
@@ -12,12 +10,11 @@ from rest_framework_extensions.exceptions import PreconditionRequiredException
 
 from rest_framework_extensions.utils import prepare_header_name
 from rest_framework_extensions.settings import extensions_api_settings
-from django.utils import six
 
 logger = logging.getLogger('django.request')
 
 
-class ETAGProcessor(object):
+class ETAGProcessor:
     """Based on https://github.com/django/django/blob/master/django/views/decorators/http.py"""
 
     def __init__(self, etag_func=None, rebuild_after_method_evaluation=False):
@@ -29,7 +26,7 @@ class ETAGProcessor(object):
     def __call__(self, func):
         this = self
 
-        @wraps(func, assigned=available_attrs(func))
+        @wraps(func, assigned=WRAPPER_ASSIGNMENTS)
         def inner(self, request, *args, **kwargs):
             return this.process_conditional_request(
                 view_instance=self,
@@ -60,9 +57,11 @@ class ETAGProcessor(object):
             if request.method in SAFE_METHODS:
                 response = Response(status=status.HTTP_304_NOT_MODIFIED)
             else:
-                response = self._get_and_log_precondition_failed_response(request=request)
+                response = self._get_and_log_precondition_failed_response(
+                    request=request)
         elif self.is_if_match_failed(res_etag, etags, if_match):
-            response = self._get_and_log_precondition_failed_response(request=request)
+            response = self._get_and_log_precondition_failed_response(
+                request=request)
         else:
             response = view_method(view_instance, request, *args, **kwargs)
             if self.rebuild_after_method_evaluation:
@@ -103,7 +102,7 @@ class ETAGProcessor(object):
                        request,
                        args,
                        kwargs):
-        if isinstance(self.etag_func, six.string_types):
+        if isinstance(self.etag_func, str):
             etag_func = getattr(view_instance, self.etag_func)
         else:
             etag_func = self.etag_func
@@ -168,7 +167,7 @@ class APIETAGProcessor(ETAGProcessor):
                                                          'the key is the HTTP verb, and the value is a list of '
                                                          'HTTP headers that must all be present for that request.')
 
-        super(APIETAGProcessor, self).__init__(etag_func=etag_func,
+        super().__init__(etag_func=etag_func,
                                                rebuild_after_method_evaluation=rebuild_after_method_evaluation)
 
     def get_etags_and_matchers(self, request):
@@ -176,12 +175,13 @@ class APIETAGProcessor(ETAGProcessor):
         # evaluate the preconditions, raises 428 if condition is not met
         self.evaluate_preconditions(request)
         # alright, headers are present, extract the values and match the conditions
-        return super(APIETAGProcessor, self).get_etags_and_matchers(request)
+        return super().get_etags_and_matchers(request)
 
     def evaluate_preconditions(self, request):
         """Evaluate whether the precondition for the request is met."""
         if request.method.upper() in self.precondition_map.keys():
-            required_headers = self.precondition_map.get(request.method.upper(), [])
+            required_headers = self.precondition_map.get(
+                request.method.upper(), [])
             # check the required headers
             for header in required_headers:
                 if not request.META.get(prepare_header_name(header)):
@@ -195,7 +195,8 @@ class APIETAGProcessor(ETAGProcessor):
                     # raise an RFC 6585 compliant exception
                     raise PreconditionRequiredException(detail='Precondition required. This "%s" request '
                                                                'is required to be conditional. '
-                                                               'Try again using "%s".' % (request.method, header)
+                                                               'Try again using "%s".' % (
+                                                                   request.method, header)
                                                         )
         return True
 
