@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import json
 
 from django.contrib.auth.models import User, Group, Permission
@@ -12,7 +11,7 @@ from tests_app.testutils import basic_auth_header
 from .models import PermissionsComment
 
 
-class ExtendedDjangoObjectPermissionTestMixin(object):
+class ExtendedDjangoObjectPermissionTestMixin:
     def setUp(self):
         from guardian.shortcuts import assign_perm
 
@@ -28,8 +27,8 @@ class ExtendedDjangoObjectPermissionTestMixin(object):
         # create custom permission
         Permission.objects.get_or_create(
             codename='view_permissionscomment',
-            name='Can view comment',
-            content_type=ContentType.objects.get_for_model(PermissionsComment)
+            content_type=ContentType.objects.get_for_model(PermissionsComment),
+            defaults={'name': 'Can view comment'},
         )
 
         # give everyone model level permissions, as we are not testing those
