@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from django.test import TestCase
 from django.utils.http import quote_etag
 
@@ -169,7 +168,7 @@ class ETAGProcessorTestBehavior_rebuild_after_method_evaluation(TestCase):
         self.assertEqual(response.data, 'Response from method')
 
 
-class ETAGProcessorTestBehaviorMixin(object):
+class ETAGProcessorTestBehaviorMixin:
     def setUp(self):
         def calculate_etag(**kwargs):
             return '123'
@@ -222,7 +221,7 @@ class ETAGProcessorTestBehaviorMixin(object):
 
 class ETAGProcessorTestBehavior_if_none_match(ETAGProcessorTestBehaviorMixin, TestCase):
     def setUp(self):
-        super(ETAGProcessorTestBehavior_if_none_match, self).setUp()
+        super().setUp()
         self.header_name = 'if-none-match'
         self.experiments = [
             {
@@ -276,7 +275,7 @@ class ETAGProcessorTestBehavior_if_none_match(ETAGProcessorTestBehaviorMixin, Te
 
 class ETAGProcessorTestBehavior_if_match(ETAGProcessorTestBehaviorMixin, TestCase):
     def setUp(self):
-        super(ETAGProcessorTestBehavior_if_match, self).setUp()
+        super().setUp()
         self.header_name = 'if-match'
         self.experiments = [
             {
@@ -343,7 +342,7 @@ class APIETAGProcessorTest(TestCase):
             class View(views.APIView):
                 @api_etag()
                 def get(self, request, *args, **kwargs):
-                    return super(View, self).get(request, *args, **kwargs)
+                    return super().get(request, *args, **kwargs)
 
     def test_should_raise_assertion_error_if_precondition_map_not_a_dict(self):
         with self.assertRaises(AssertionError):
@@ -354,7 +353,7 @@ class APIETAGProcessorTest(TestCase):
             class View(views.APIView):
                 @api_etag(dummy_api_etag_func, precondition_map=['header-name'])
                 def get(self, request, *args, **kwargs):
-                    return super(View, self).get(request, *args, **kwargs)
+                    return super().get(request, *args, **kwargs)
 
     def test_should_add_object_etag_value(self):
         class TestView(views.APIView):
@@ -393,10 +392,6 @@ class APIETAGProcessorTest(TestCase):
         self.assertEqual(response.data, 'Response from GET method')
 
 
-
-
-
-
     def test_should_require_precondition_decorator_unsafe_methods_empty(self):
         class TestView(views.APIView):
             @api_etag(dummy_api_etag_func, precondition_map={})
@@ -526,7 +521,7 @@ class APIETAGProcessorTest(TestCase):
         self.assertIsNotNone(cm.exception.detail)
 
 
-class APIETAGProcessorTestBehaviorMixin(object):
+class APIETAGProcessorTestBehaviorMixin:
     def setUp(self):
         def calculate_etag(**kwargs):
             return '123'
@@ -613,7 +608,7 @@ class APIETAGProcessorTestBehaviorMixin(object):
 
 class APIETAGProcessorTestBehavior_if_match(APIETAGProcessorTestBehaviorMixin, TestCase):
     def setUp(self):
-        super(APIETAGProcessorTestBehavior_if_match, self).setUp()
+        super().setUp()
         self.header_name = 'if-match'
         self.experiments = [
             {
@@ -667,7 +662,7 @@ class APIETAGProcessorTestBehavior_if_match(APIETAGProcessorTestBehaviorMixin, T
 
 class APIETAGProcessorTestBehavior_if_none_match(APIETAGProcessorTestBehaviorMixin, TestCase):
     def setUp(self):
-        super(APIETAGProcessorTestBehavior_if_none_match, self).setUp()
+        super().setUp()
         self.header_name = 'if-none-match'
         self.experiments = [
             {
